# File: primitive_lib.py 
# Author(s): Saswati Ray
# Created: Wed Feb 17 06:44:20 EST 2021 
# Description:
# Acknowledgements:
# Copyright (c) 2021 Carnegie Mellon University
# This code is subject to the license terms contained in the code repo.

import d3m.index
import d3m.metadata.base as metadata
import logging
import sys
from timeit import default_timer as timer

# AutonML imports
import autonml.primitivedescription as primitivedescription

def list_primitives():
    """
    Returns a list of all primitives, as PrimitiveMetadata[].
    """
    primcs = []
    prims = d3m.index.search()
        
    for pc in prims:
        # Do not load expensive primitives! These ones have been reported to take very long making TA2 unavailable!
        if 'Cornell' in pc:# or 'Umich' in pc:
            continue
        if 'GCN' in pc or 'graph_to_edge_list.DSBOX' in pc or 'multilabel_classifier.DSBOX' in pc:
            continue
        try:
            primitive_obj = d3m.index.get_primitive(pc)
        except:
            print("problem with ", pc)
            print(sys.exc_info()[0])
            continue

        if hasattr(primitive_obj, 'metadata'):
            try:
                primitive = PrimitiveMetadata(primitive_obj.metadata, primitive_obj)
            except:
                continue
            primcs.append(primitive)

    return primcs
 
class PrimitiveMetadata(object):
    """
    A class that mainly just contains primitive metadata.
    """
    def __init__(self, metadata, classname):
        self.id = metadata.query()['id']
        self.name = metadata.query()['name']
        self.version = metadata.query()['version']
        self.python_path = metadata.query()['python_path'] 
        self.classname = classname
        self.family = metadata.query()['primitive_family']
        self.digest = metadata.query()['digest']

        self.arguments=[]
        args = metadata.query()['primitive_code']['arguments']
        for name,value in args.items():
            if value['kind'] == "PIPELINE":
                self.arguments.append(name)

        self.produce_methods=[]
        args = metadata.query()['primitive_code']['instance_methods']
        for name,value in args.items():
            if value['kind'] == "PRODUCE":
                self.produce_methods.append(name)

def load_primitives():
    """
    Return dictionary of primitivename-to-PrimitiveDescription class object.
    """
    start = timer()
    primitives = {}
    for p in list_primitives():

        primitives[p.classname] = primitivedescription.PrimitiveDescription(p.classname, p)

    end = timer()
    logging.info("Time taken to load primitives: %s seconds", end - start)
    return primitives




# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.

# import os
# import sys
# sys.path.insert(0, os.path.abspath('..'))


# -- Project information -----------------------------------------------------

project = 'Auton^n ML'
copyright = '2021, Auton Lab, Carnegie Mellon University'
author = 'Saswati Ray, Jessie Chen, Stefania La Vattiata, Artur Dubrawski'


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
#extensions = ['sphinx.ext.autodoc', 'sphinx.ext.napoleon', 'nbsphinx']
extensions = ['sphinx.ext.autodoc', 'sphinx.ext.autosectionlabel', 'nbsphinx']

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

pygments_style = 'sphinx'


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
# html_theme = 'sphinx_rtd_theme'
html_theme = 'sphinx_rtd_theme'
html_theme_options = {
    'logo_only': True,
    'collapse_navigation': False,
}
html_logo='img/AutonML_logo_w.png'
#html_favicon='_static/img/favicon.ico'

html_css_files = '_static/css/custom.css'

# Custom sidebar templates, maps document names to template names.
html_sidebars = {
    '**': [
        'about.html', 'navigation.html', 'searchbox.html',
    ]
}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

autoclass_content = 'both'
autodoc_typehints = 'description'



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

# AutonML imports
import autonml.primitive_pb2 as primitive__pb2
import autonml.value_pb2 as value__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='pipeline.proto',
  package='',
  syntax='proto3',
  serialized_options=b'Z\010pipeline',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0epipeline.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x0fprimitive.proto\x1a\x0bvalue.proto\"!\n\x11\x43ontainerArgument\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"\"\n\x12\x43ontainerArguments\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\t\"\x1c\n\x0c\x44\x61taArgument\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"\x1d\n\rDataArguments\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\t\"!\n\x11PrimitiveArgument\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x05\"\"\n\x12PrimitiveArguments\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x05\"%\n\rValueArgument\x12\x14\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x06.Value\"\x9a\x01\n\x15PrimitiveStepArgument\x12\'\n\tcontainer\x18\x01 \x01(\x0b\x32\x12.ContainerArgumentH\x00\x12\x1d\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\r.DataArgumentH\x00\x12-\n\x0e\x63ontainer_list\x18\x03 \x01(\x0b\x32\x13.ContainerArgumentsH\x00\x42\n\n\x08\x61rgument\"\x8e\x02\n\x1bPrimitiveStepHyperparameter\x12\'\n\tcontainer\x18\x01 \x01(\x0b\x32\x12.ContainerArgumentH\x00\x12\x1d\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\r.DataArgumentH\x00\x12\'\n\tprimitive\x18\x03 \x01(\x0b\x32\x12.PrimitiveArgumentH\x00\x12\x1f\n\x05value\x18\x04 \x01(\x0b\x32\x0e.ValueArgumentH\x00\x12\"\n\x08\x64\x61ta_set\x18\x05 \x01(\x0b\x32\x0e.DataArgumentsH\x00\x12-\n\x0eprimitives_set\x18\x06 \x01(\x0b\x32\x13.PrimitiveArgumentsH\x00\x42\n\n\x08\x61rgument\"\x19\n\tStepInput\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"\x18\n\nStepOutput\x12\n\n\x02id\x18\x01 \x01(\t\"X\n\x0ePipelineSource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontact\x18\x02 \x01(\t\x12\'\n\tpipelines\x18\x03 \x03(\x0b\x32\x14.PipelineDescription\"H\n\x17PipelineDescriptionUser\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x11\n\trationale\x18\x03 \x01(\t\"(\n\x18PipelineDescriptionInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"7\n\x19PipelineDescriptionOutput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\xb2\x03\n PrimitivePipelineDescriptionStep\x12\x1d\n\tprimitive\x18\x01 \x01(\x0b\x32\n.Primitive\x12\x43\n\targuments\x18\x02 \x03(\x0b\x32\x30.PrimitivePipelineDescriptionStep.ArgumentsEntry\x12\x1c\n\x07outputs\x18\x03 \x03(\x0b\x32\x0b.StepOutput\x12G\n\x0bhyperparams\x18\x04 \x03(\x0b\x32\x32.PrimitivePipelineDescriptionStep.HyperparamsEntry\x12\'\n\x05users\x18\x05 \x03(\x0b\x32\x18.PipelineDescriptionUser\x1aH\n\x0e\x41rgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.PrimitiveStepArgument:\x02\x38\x01\x1aP\n\x10HyperparamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.PrimitiveStepHyperparameter:\x02\x38\x01\"\x86\x01\n\"SubpipelinePipelineDescriptionStep\x12&\n\x08pipeline\x18\x01 \x01(\x0b\x32\x14.PipelineDescription\x12\x1a\n\x06inputs\x18\x02 \x03(\x0b\x32\n.StepInput\x12\x1c\n\x07outputs\x18\x03 \x03(\x0b\x32\x0b.StepOutput\"^\n\"PlaceholderPipelineDescriptionStep\x12\x1a\n\x06inputs\x18\x01 \x03(\x0b\x32\n.StepInput\x12\x1c\n\x07outputs\x18\x02 \x03(\x0b\x32\x0b.StepOutput\"\xce\x01\n\x17PipelineDescriptionStep\x12\x36\n\tprimitive\x18\x01 \x01(\x0b\x32!.PrimitivePipelineDescriptionStepH\x00\x12\x37\n\x08pipeline\x18\x02 \x01(\x0b\x32#.SubpipelinePipelineDescriptionStepH\x00\x12:\n\x0bplaceholder\x18\x03 \x01(\x0b\x32#.PlaceholderPipelineDescriptionStepH\x00\x42\x06\n\x04step\"\xcc\x02\n\x13PipelineDescription\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1f\n\x06source\x18\x02 \x01(\x0b\x32\x0f.PipelineSource\x12+\n\x07\x63reated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\'\n\x05users\x18\x07 \x03(\x0b\x32\x18.PipelineDescriptionUser\x12)\n\x06inputs\x18\x08 \x03(\x0b\x32\x19.PipelineDescriptionInput\x12+\n\x07outputs\x18\t \x03(\x0b\x32\x1a.PipelineDescriptionOutput\x12\'\n\x05steps\x18\n \x03(\x0b\x32\x18.PipelineDescriptionStep\x12\x0e\n\x06\x64igest\x18\x0b \x01(\tB\nZ\x08pipelineb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,primitive__pb2.DESCRIPTOR,value__pb2.DESCRIPTOR,])




_CONTAINERARGUMENT = _descriptor.Descriptor(
  name='ContainerArgument',
  full_name='ContainerArgument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='ContainerArgument.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=114,
)


_CONTAINERARGUMENTS = _descriptor.Descriptor(
  name='ContainerArguments',
  full_name='ContainerArguments',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='ContainerArguments.data', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=150,
)


_DATAARGUMENT = _descriptor.Descriptor(
  name='DataArgument',
  full_name='DataArgument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='DataArgument.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=180,
)


_DATAARGUMENTS = _descriptor.Descriptor(
  name='DataArguments',
  full_name='DataArguments',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='DataArguments.data', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=211,
)


_PRIMITIVEARGUMENT = _descriptor.Descriptor(
  name='PrimitiveArgument',
  full_name='PrimitiveArgument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='PrimitiveArgument.data', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=246,
)


_PRIMITIVEARGUMENTS = _descriptor.Descriptor(
  name='PrimitiveArguments',
  full_name='PrimitiveArguments',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='PrimitiveArguments.data', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=282,
)


_VALUEARGUMENT = _descriptor.Descriptor(
  name='ValueArgument',
  full_name='ValueArgument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='ValueArgument.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=321,
)


_PRIMITIVESTEPARGUMENT = _descriptor.Descriptor(
  name='PrimitiveStepArgument',
  full_name='PrimitiveStepArgument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container', full_name='PrimitiveStepArgument.container', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='PrimitiveStepArgument.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='container_list', full_name='PrimitiveStepArgument.container_list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='argument', full_name='PrimitiveStepArgument.argument',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=324,
  serialized_end=478,
)


_PRIMITIVESTEPHYPERPARAMETER = _descriptor.Descriptor(
  name='PrimitiveStepHyperparameter',
  full_name='PrimitiveStepHyperparameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container', full_name='PrimitiveStepHyperparameter.container', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='PrimitiveStepHyperparameter.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primitive', full_name='PrimitiveStepHyperparameter.primitive', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='PrimitiveStepHyperparameter.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_set', full_name='PrimitiveStepHyperparameter.data_set', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primitives_set', full_name='PrimitiveStepHyperparameter.primitives_set', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='argument', full_name='PrimitiveStepHyperparameter.argument',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=481,
  serialized_end=751,
)


_STEPINPUT = _descriptor.Descriptor(
  name='StepInput',
  full_name='StepInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='StepInput.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=753,
  serialized_end=778,
)


_STEPOUTPUT = _descriptor.Descriptor(
  name='StepOutput',
  full_name='StepOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='StepOutput.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=804,
)


_PIPELINESOURCE = _descriptor.Descriptor(
  name='PipelineSource',
  full_name='PipelineSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='PipelineSource.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contact', full_name='PipelineSource.contact', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pipelines', full_name='PipelineSource.pipelines', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=806,
  serialized_end=894,
)


_PIPELINEDESCRIPTIONUSER = _descriptor.Descriptor(
  name='PipelineDescriptionUser',
  full_name='PipelineDescriptionUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='PipelineDescriptionUser.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='PipelineDescriptionUser.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rationale', full_name='PipelineDescriptionUser.rationale', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=968,
)


_PIPELINEDESCRIPTIONINPUT = _descriptor.Descriptor(
  name='PipelineDescriptionInput',
  full_name='PipelineDescriptionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='PipelineDescriptionInput.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=970,
  serialized_end=1010,
)


_PIPELINEDESCRIPTIONOUTPUT = _descriptor.Descriptor(
  name='PipelineDescriptionOutput',
  full_name='PipelineDescriptionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='PipelineDescriptionOutput.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='PipelineDescriptionOutput.data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1012,
  serialized_end=1067,
)


_PRIMITIVEPIPELINEDESCRIPTIONSTEP_ARGUMENTSENTRY = _descriptor.Descriptor(
  name='ArgumentsEntry',
  full_name='PrimitivePipelineDescriptionStep.ArgumentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='PrimitivePipelineDescriptionStep.ArgumentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='PrimitivePipelineDescriptionStep.ArgumentsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1350,
  serialized_end=1422,
)

_PRIMITIVEPIPELINEDESCRIPTIONSTEP_HYPERPARAMSENTRY = _descriptor.Descriptor(
  name='HyperparamsEntry',
  full_name='PrimitivePipelineDescriptionStep.HyperparamsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='PrimitivePipelineDescriptionStep.HyperparamsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='PrimitivePipelineDescriptionStep.HyperparamsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1424,
  serialized_end=1504,
)

_PRIMITIVEPIPELINEDESCRIPTIONSTEP = _descriptor.Descriptor(
  name='PrimitivePipelineDescriptionStep',
  full_name='PrimitivePipelineDescriptionStep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primitive', full_name='PrimitivePipelineDescriptionStep.primitive', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='PrimitivePipelineDescriptionStep.arguments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='PrimitivePipelineDescriptionStep.outputs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hyperparams', full_name='PrimitivePipelineDescriptionStep.hyperparams', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='PrimitivePipelineDescriptionStep.users', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PRIMITIVEPIPELINEDESCRIPTIONSTEP_ARGUMENTSENTRY, _PRIMITIVEPIPELINEDESCRIPTIONSTEP_HYPERPARAMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1070,
  serialized_end=1504,
)


_SUBPIPELINEPIPELINEDESCRIPTIONSTEP = _descriptor.Descriptor(
  name='SubpipelinePipelineDescriptionStep',
  full_name='SubpipelinePipelineDescriptionStep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='SubpipelinePipelineDescriptionStep.pipeline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='SubpipelinePipelineDescriptionStep.inputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='SubpipelinePipelineDescriptionStep.outputs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1507,
  serialized_end=1641,
)


_PLACEHOLDERPIPELINEDESCRIPTIONSTEP = _descriptor.Descriptor(
  name='PlaceholderPipelineDescriptionStep',
  full_name='PlaceholderPipelineDescriptionStep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='PlaceholderPipelineDescriptionStep.inputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='PlaceholderPipelineDescriptionStep.outputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1643,
  serialized_end=1737,
)


_PIPELINEDESCRIPTIONSTEP = _descriptor.Descriptor(
  name='PipelineDescriptionStep',
  full_name='PipelineDescriptionStep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primitive', full_name='PipelineDescriptionStep.primitive', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='PipelineDescriptionStep.pipeline', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placeholder', full_name='PipelineDescriptionStep.placeholder', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='step', full_name='PipelineDescriptionStep.step',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1740,
  serialized_end=1946,
)


_PIPELINEDESCRIPTION = _descriptor.Descriptor(
  name='PipelineDescription',
  full_name='PipelineDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='PipelineDescription.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='PipelineDescription.source', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='PipelineDescription.created', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='PipelineDescription.name', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='PipelineDescription.description', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='PipelineDescription.users', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='PipelineDescription.inputs', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='PipelineDescription.outputs', index=7,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steps', full_name='PipelineDescription.steps', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digest', full_name='PipelineDescription.digest', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1949,
  serialized_end=2281,
)

_VALUEARGUMENT.fields_by_name['data'].message_type = value__pb2._VALUE
_PRIMITIVESTEPARGUMENT.fields_by_name['container'].message_type = _CONTAINERARGUMENT
_PRIMITIVESTEPARGUMENT.fields_by_name['data'].message_type = _DATAARGUMENT
_PRIMITIVESTEPARGUMENT.fields_by_name['container_list'].message_type = _CONTAINERARGUMENTS
_PRIMITIVESTEPARGUMENT.oneofs_by_name['argument'].fields.append(
  _PRIMITIVESTEPARGUMENT.fields_by_name['container'])
_PRIMITIVESTEPARGUMENT.fields_by_name['container'].containing_oneof = _PRIMITIVESTEPARGUMENT.oneofs_by_name['argument']
_PRIMITIVESTEPARGUMENT.oneofs_by_name['argument'].fields.append(
  _PRIMITIVESTEPARGUMENT.fields_by_name['data'])
_PRIMITIVESTEPARGUMENT.fields_by_name['data'].containing_oneof = _PRIMITIVESTEPARGUMENT.oneofs_by_name['argument']
_PRIMITIVESTEPARGUMENT.oneofs_by_name['argument'].fields.append(
  _PRIMITIVESTEPARGUMENT.fields_by_name['container_list'])
_PRIMITIVESTEPARGUMENT.fields_by_name['container_list'].containing_oneof = _PRIMITIVESTEPARGUMENT.oneofs_by_name['argument']
_PRIMITIVESTEPHYPERPARAMETER.fields_by_name['container'].message_type = _CONTAINERARGUMENT
_PRIMITIVESTEPHYPERPARAMETER.fields_by_name['data'].message_type = _DATAARGUMENT
_PRIMITIVESTEPHYPERPARAMETER.fields_by_name['primitive'].message_type = _PRIMITIVEARGUMENT
_PRIMITIVESTEPHYPERPARAMETER.fields_by_name['value'].message_type = _VALUEARGUMENT
_PRIMITIVESTEPHYPERPARAMETER.fields_by_name['data_set'].message_type = _DATAARGUMENTS
_PRIMITIVESTEPHYPERPARAMETER.fields_by_name['primitives_set'].message_type = _PRIMITIVEARGUMENTS
_PRIMITIVESTEPHYPERPARAMETER.oneofs_by_name['argument'].fields.append(
  _PRIMITIVESTEPHYPERPARAMETER.fields_by_name['container'])
_PRIMITIVESTEPHYPERPARAMETER.fields_by_name['container'].containing_oneof = _PRIMITIVESTEPHYPERPARAMETER.oneofs_by_name['argument']
_PRIMITIVESTEPHYPERPARAMETER.oneofs_by_name['argument'].fields.append(
  _PRIMITIVESTEPHYPERPARAMETER.fields_by_name['data'])
_PRIMITIVESTEPHYPERPARAMETER.fields_by_name['data'].containing_oneof = _PRIMITIVESTEPHYPERPARAMETER.oneofs_by_name['argument']
_PRIMITIVESTEPHYPERPARAMETER.oneofs_by_name['argument'].fields.append(
  _PRIMITIVESTEPHYPERPARAMETER.fields_by_name['primitive'])
_PRIMITIVESTEPHYPERPARAMETER.fields_by_name['primitive'].containing_oneof = _PRIMITIVESTEPHYPERPARAMETER.oneofs_by_name['argument']
_PRIMITIVESTEPHYPERPARAMETER.oneofs_by_name['argument'].fields.append(
  _PRIMITIVESTEPHYPERPARAMETER.fields_by_name['value'])
_PRIMITIVESTEPHYPERPARAMETER.fields_by_name['value'].containing_oneof = _PRIMITIVESTEPHYPERPARAMETER.oneofs_by_name['argument']
_PRIMITIVESTEPHYPERPARAMETER.oneofs_by_name['argument'].fields.append(
  _PRIMITIVESTEPHYPERPARAMETER.fields_by_name['data_set'])
_PRIMITIVESTEPHYPERPARAMETER.fields_by_name['data_set'].containing_oneof = _PRIMITIVESTEPHYPERPARAMETER.oneofs_by_name['argument']
_PRIMITIVESTEPHYPERPARAMETER.oneofs_by_name['argument'].fields.append(
  _PRIMITIVESTEPHYPERPARAMETER.fields_by_name['primitives_set'])
_PRIMITIVESTEPHYPERPARAMETER.fields_by_name['primitives_set'].containing_oneof = _PRIMITIVESTEPHYPERPARAMETER.oneofs_by_name['argument']
_PIPELINESOURCE.fields_by_name['pipelines'].message_type = _PIPELINEDESCRIPTION
_PRIMITIVEPIPELINEDESCRIPTIONSTEP_ARGUMENTSENTRY.fields_by_name['value'].message_type = _PRIMITIVESTEPARGUMENT
_PRIMITIVEPIPELINEDESCRIPTIONSTEP_ARGUMENTSENTRY.containing_type = _PRIMITIVEPIPELINEDESCRIPTIONSTEP
_PRIMITIVEPIPELINEDESCRIPTIONSTEP_HYPERPARAMSENTRY.fields_by_name['value'].message_type = _PRIMITIVESTEPHYPERPARAMETER
_PRIMITIVEPIPELINEDESCRIPTIONSTEP_HYPERPARAMSENTRY.containing_type = _PRIMITIVEPIPELINEDESCRIPTIONSTEP
_PRIMITIVEPIPELINEDESCRIPTIONSTEP.fields_by_name['primitive'].message_type = primitive__pb2._PRIMITIVE
_PRIMITIVEPIPELINEDESCRIPTIONSTEP.fields_by_name['arguments'].message_type = _PRIMITIVEPIPELINEDESCRIPTIONSTEP_ARGUMENTSENTRY
_PRIMITIVEPIPELINEDESCRIPTIONSTEP.fields_by_name['outputs'].message_type = _STEPOUTPUT
_PRIMITIVEPIPELINEDESCRIPTIONSTEP.fields_by_name['hyperparams'].message_type = _PRIMITIVEPIPELINEDESCRIPTIONSTEP_HYPERPARAMSENTRY
_PRIMITIVEPIPELINEDESCRIPTIONSTEP.fields_by_name['users'].message_type = _PIPELINEDESCRIPTIONUSER
_SUBPIPELINEPIPELINEDESCRIPTIONSTEP.fields_by_name['pipeline'].message_type = _PIPELINEDESCRIPTION
_SUBPIPELINEPIPELINEDESCRIPTIONSTEP.fields_by_name['inputs'].message_type = _STEPINPUT
_SUBPIPELINEPIPELINEDESCRIPTIONSTEP.fields_by_name['outputs'].message_type = _STEPOUTPUT
_PLACEHOLDERPIPELINEDESCRIPTIONSTEP.fields_by_name['inputs'].message_type = _STEPINPUT
_PLACEHOLDERPIPELINEDESCRIPTIONSTEP.fields_by_name['outputs'].message_type = _STEPOUTPUT
_PIPELINEDESCRIPTIONSTEP.fields_by_name['primitive'].message_type = _PRIMITIVEPIPELINEDESCRIPTIONSTEP
_PIPELINEDESCRIPTIONSTEP.fields_by_name['pipeline'].message_type = _SUBPIPELINEPIPELINEDESCRIPTIONSTEP
_PIPELINEDESCRIPTIONSTEP.fields_by_name['placeholder'].message_type = _PLACEHOLDERPIPELINEDESCRIPTIONSTEP
_PIPELINEDESCRIPTIONSTEP.oneofs_by_name['step'].fields.append(
  _PIPELINEDESCRIPTIONSTEP.fields_by_name['primitive'])
_PIPELINEDESCRIPTIONSTEP.fields_by_name['primitive'].containing_oneof = _PIPELINEDESCRIPTIONSTEP.oneofs_by_name['step']
_PIPELINEDESCRIPTIONSTEP.oneofs_by_name['step'].fields.append(
  _PIPELINEDESCRIPTIONSTEP.fields_by_name['pipeline'])
_PIPELINEDESCRIPTIONSTEP.fields_by_name['pipeline'].containing_oneof = _PIPELINEDESCRIPTIONSTEP.oneofs_by_name['step']
_PIPELINEDESCRIPTIONSTEP.oneofs_by_name['step'].fields.append(
  _PIPELINEDESCRIPTIONSTEP.fields_by_name['placeholder'])
_PIPELINEDESCRIPTIONSTEP.fields_by_name['placeholder'].containing_oneof = _PIPELINEDESCRIPTIONSTEP.oneofs_by_name['step']
_PIPELINEDESCRIPTION.fields_by_name['source'].message_type = _PIPELINESOURCE
_PIPELINEDESCRIPTION.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PIPELINEDESCRIPTION.fields_by_name['users'].message_type = _PIPELINEDESCRIPTIONUSER
_PIPELINEDESCRIPTION.fields_by_name['inputs'].message_type = _PIPELINEDESCRIPTIONINPUT
_PIPELINEDESCRIPTION.fields_by_name['outputs'].message_type = _PIPELINEDESCRIPTIONOUTPUT
_PIPELINEDESCRIPTION.fields_by_name['steps'].message_type = _PIPELINEDESCRIPTIONSTEP
DESCRIPTOR.message_types_by_name['ContainerArgument'] = _CONTAINERARGUMENT
DESCRIPTOR.message_types_by_name['ContainerArguments'] = _CONTAINERARGUMENTS
DESCRIPTOR.message_types_by_name['DataArgument'] = _DATAARGUMENT
DESCRIPTOR.message_types_by_name['DataArguments'] = _DATAARGUMENTS
DESCRIPTOR.message_types_by_name['PrimitiveArgument'] = _PRIMITIVEARGUMENT
DESCRIPTOR.message_types_by_name['PrimitiveArguments'] = _PRIMITIVEARGUMENTS
DESCRIPTOR.message_types_by_name['ValueArgument'] = _VALUEARGUMENT
DESCRIPTOR.message_types_by_name['PrimitiveStepArgument'] = _PRIMITIVESTEPARGUMENT
DESCRIPTOR.message_types_by_name['PrimitiveStepHyperparameter'] = _PRIMITIVESTEPHYPERPARAMETER
DESCRIPTOR.message_types_by_name['StepInput'] = _STEPINPUT
DESCRIPTOR.message_types_by_name['StepOutput'] = _STEPOUTPUT
DESCRIPTOR.message_types_by_name['PipelineSource'] = _PIPELINESOURCE
DESCRIPTOR.message_types_by_name['PipelineDescriptionUser'] = _PIPELINEDESCRIPTIONUSER
DESCRIPTOR.message_types_by_name['PipelineDescriptionInput'] = _PIPELINEDESCRIPTIONINPUT
DESCRIPTOR.message_types_by_name['PipelineDescriptionOutput'] = _PIPELINEDESCRIPTIONOUTPUT
DESCRIPTOR.message_types_by_name['PrimitivePipelineDescriptionStep'] = _PRIMITIVEPIPELINEDESCRIPTIONSTEP
DESCRIPTOR.message_types_by_name['SubpipelinePipelineDescriptionStep'] = _SUBPIPELINEPIPELINEDESCRIPTIONSTEP
DESCRIPTOR.message_types_by_name['PlaceholderPipelineDescriptionStep'] = _PLACEHOLDERPIPELINEDESCRIPTIONSTEP
DESCRIPTOR.message_types_by_name['PipelineDescriptionStep'] = _PIPELINEDESCRIPTIONSTEP
DESCRIPTOR.message_types_by_name['PipelineDescription'] = _PIPELINEDESCRIPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ContainerArgument = _reflection.GeneratedProtocolMessageType('ContainerArgument', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERARGUMENT,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:ContainerArgument)
  })
_sym_db.RegisterMessage(ContainerArgument)

ContainerArguments = _reflection.GeneratedProtocolMessageType('ContainerArguments', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERARGUMENTS,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:ContainerArguments)
  })
_sym_db.RegisterMessage(ContainerArguments)

DataArgument = _reflection.GeneratedProtocolMessageType('DataArgument', (_message.Message,), {
  'DESCRIPTOR' : _DATAARGUMENT,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:DataArgument)
  })
_sym_db.RegisterMessage(DataArgument)

DataArguments = _reflection.GeneratedProtocolMessageType('DataArguments', (_message.Message,), {
  'DESCRIPTOR' : _DATAARGUMENTS,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:DataArguments)
  })
_sym_db.RegisterMessage(DataArguments)

PrimitiveArgument = _reflection.GeneratedProtocolMessageType('PrimitiveArgument', (_message.Message,), {
  'DESCRIPTOR' : _PRIMITIVEARGUMENT,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:PrimitiveArgument)
  })
_sym_db.RegisterMessage(PrimitiveArgument)

PrimitiveArguments = _reflection.GeneratedProtocolMessageType('PrimitiveArguments', (_message.Message,), {
  'DESCRIPTOR' : _PRIMITIVEARGUMENTS,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:PrimitiveArguments)
  })
_sym_db.RegisterMessage(PrimitiveArguments)

ValueArgument = _reflection.GeneratedProtocolMessageType('ValueArgument', (_message.Message,), {
  'DESCRIPTOR' : _VALUEARGUMENT,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:ValueArgument)
  })
_sym_db.RegisterMessage(ValueArgument)

PrimitiveStepArgument = _reflection.GeneratedProtocolMessageType('PrimitiveStepArgument', (_message.Message,), {
  'DESCRIPTOR' : _PRIMITIVESTEPARGUMENT,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:PrimitiveStepArgument)
  })
_sym_db.RegisterMessage(PrimitiveStepArgument)

PrimitiveStepHyperparameter = _reflection.GeneratedProtocolMessageType('PrimitiveStepHyperparameter', (_message.Message,), {
  'DESCRIPTOR' : _PRIMITIVESTEPHYPERPARAMETER,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:PrimitiveStepHyperparameter)
  })
_sym_db.RegisterMessage(PrimitiveStepHyperparameter)

StepInput = _reflection.GeneratedProtocolMessageType('StepInput', (_message.Message,), {
  'DESCRIPTOR' : _STEPINPUT,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:StepInput)
  })
_sym_db.RegisterMessage(StepInput)

StepOutput = _reflection.GeneratedProtocolMessageType('StepOutput', (_message.Message,), {
  'DESCRIPTOR' : _STEPOUTPUT,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:StepOutput)
  })
_sym_db.RegisterMessage(StepOutput)

PipelineSource = _reflection.GeneratedProtocolMessageType('PipelineSource', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINESOURCE,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:PipelineSource)
  })
_sym_db.RegisterMessage(PipelineSource)

PipelineDescriptionUser = _reflection.GeneratedProtocolMessageType('PipelineDescriptionUser', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINEDESCRIPTIONUSER,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:PipelineDescriptionUser)
  })
_sym_db.RegisterMessage(PipelineDescriptionUser)

PipelineDescriptionInput = _reflection.GeneratedProtocolMessageType('PipelineDescriptionInput', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINEDESCRIPTIONINPUT,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:PipelineDescriptionInput)
  })
_sym_db.RegisterMessage(PipelineDescriptionInput)

PipelineDescriptionOutput = _reflection.GeneratedProtocolMessageType('PipelineDescriptionOutput', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINEDESCRIPTIONOUTPUT,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:PipelineDescriptionOutput)
  })
_sym_db.RegisterMessage(PipelineDescriptionOutput)

PrimitivePipelineDescriptionStep = _reflection.GeneratedProtocolMessageType('PrimitivePipelineDescriptionStep', (_message.Message,), {

  'ArgumentsEntry' : _reflection.GeneratedProtocolMessageType('ArgumentsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PRIMITIVEPIPELINEDESCRIPTIONSTEP_ARGUMENTSENTRY,
    '__module__' : 'pipeline_pb2'
    # @@protoc_insertion_point(class_scope:PrimitivePipelineDescriptionStep.ArgumentsEntry)
    })
  ,

  'HyperparamsEntry' : _reflection.GeneratedProtocolMessageType('HyperparamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PRIMITIVEPIPELINEDESCRIPTIONSTEP_HYPERPARAMSENTRY,
    '__module__' : 'pipeline_pb2'
    # @@protoc_insertion_point(class_scope:PrimitivePipelineDescriptionStep.HyperparamsEntry)
    })
  ,
  'DESCRIPTOR' : _PRIMITIVEPIPELINEDESCRIPTIONSTEP,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:PrimitivePipelineDescriptionStep)
  })
_sym_db.RegisterMessage(PrimitivePipelineDescriptionStep)
_sym_db.RegisterMessage(PrimitivePipelineDescriptionStep.ArgumentsEntry)
_sym_db.RegisterMessage(PrimitivePipelineDescriptionStep.HyperparamsEntry)

SubpipelinePipelineDescriptionStep = _reflection.GeneratedProtocolMessageType('SubpipelinePipelineDescriptionStep', (_message.Message,), {
  'DESCRIPTOR' : _SUBPIPELINEPIPELINEDESCRIPTIONSTEP,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:SubpipelinePipelineDescriptionStep)
  })
_sym_db.RegisterMessage(SubpipelinePipelineDescriptionStep)

PlaceholderPipelineDescriptionStep = _reflection.GeneratedProtocolMessageType('PlaceholderPipelineDescriptionStep', (_message.Message,), {
  'DESCRIPTOR' : _PLACEHOLDERPIPELINEDESCRIPTIONSTEP,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:PlaceholderPipelineDescriptionStep)
  })
_sym_db.RegisterMessage(PlaceholderPipelineDescriptionStep)

PipelineDescriptionStep = _reflection.GeneratedProtocolMessageType('PipelineDescriptionStep', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINEDESCRIPTIONSTEP,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:PipelineDescriptionStep)
  })
_sym_db.RegisterMessage(PipelineDescriptionStep)

PipelineDescription = _reflection.GeneratedProtocolMessageType('PipelineDescription', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINEDESCRIPTION,
  '__module__' : 'pipeline_pb2'
  # @@protoc_insertion_point(class_scope:PipelineDescription)
  })
_sym_db.RegisterMessage(PipelineDescription)


DESCRIPTOR._options = None
_PRIMITIVEPIPELINEDESCRIPTIONSTEP_ARGUMENTSENTRY._options = None
_PRIMITIVEPIPELINEDESCRIPTIONSTEP_HYPERPARAMSENTRY._options = None
# @@protoc_insertion_point(module_scope)
